==> lintian_2.89.0.tar.xz: lintian-2.89.0/checks/files/date.pm <==
# files/date -- lintian check script -*- perl -*-

# Copyright © 1998 Christian Schwarz and Richard Braakman
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, you can find it on the World Wide
# Web at http://www.gnu.org/copyleft/gpl.html, or write to the Free
# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
# MA 02110-1301, USA.

package Lintian::files::date;

use v5.20;
use warnings;
use utf8;
use autodie;

use Moo;
use namespace::clean;

with 'Lintian::Check';

my $ALLOWED_ANCIENT_FILES = Lintian::Data->new('files/allowed-ancient-files');

sub visit_installed_files {
    my ($self, $file) = @_;

    my ($year) = ($file->date =~ /^(\d{4})/);

    $self->tag('package-contains-ancient-file', $file->name, $file->date)
      if $year <= 1975 # value from dak CVS: Dinstall::PastCutOffYear
      and not $ALLOWED_ANCIENT_FILES->matches_any($file->name);

    return;
}

1;

# Local Variables:
# indent-tabs-mode: nil
# cperl-indent-level: 4
# End:
# vim: syntax=perl sw=4 sts=4 sr et

==> lintian_2.104.0.tar.xz: lintian-2.104.0/checks/files/date.pm <==
# files/date -- lintian check script -*- perl -*-

# Copyright © 1998 Christian Schwarz and Richard Braakman
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, you can find it on the World Wide
# Web at http://www.gnu.org/copyleft/gpl.html, or write to the Free
# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
# MA 02110-1301, USA.

package Lintian::files::date;

use v5.20;
use warnings;
use utf8;
use autodie;

use Moo;
use namespace::clean;

with 'Lintian::Check';

my $ALLOWED_ANCIENT_FILES = Lintian::Data->new('files/allowed-ancient-files');

sub visit_installed_files {
    my ($self, $file) = @_;

    my ($year) = ($file->date =~ /^(\d{4})/);

    $self->hint('package-contains-ancient-file', $file->name, $file->date)
      if $year <= 1975 # value from dak CVS: Dinstall::PastCutOffYear
      and not $ALLOWED_ANCIENT_FILES->matches_any($file->name);

    return;
}

1;

# Local Variables:
# indent-tabs-mode: nil
# cperl-indent-level: 4
# End:
# vim: syntax=perl sw=4 sts=4 sr et
